@@ -4,15 +4,21 @@ import pandas as pd
 import pytest
 from datetime import datetime, UTC
 
-from flex_evals.schemas.results import (
+from flex_evals import (
     TestCaseSummary,
     TestCaseResult,
     EvaluationSummary,
     EvaluationRunResult,
-    ExecutionContext,
+    TestCase,
+    Output,
+    Status,
+    CheckResult,
+    CheckError,
+    Check,
+    evaluate,
+    ExperimentMetadata,
 )
-from flex_evals import TestCase, Output, Status, CheckResult, CheckError, Check, evaluate
-from flex_evals.schemas.experiments import ExperimentMetadata
+from flex_evals.schemas.results import ExecutionContext
 
 
 class TestTestCaseSummary:
@@ -21,16 +27,14 @@ class TestTestCaseSummary:
     def test_valid_summary(self):
         """Test creating valid TestCaseSummary."""
         summary = TestCaseSummary(
-            total_checks=5,
+            total_checks=4,
             completed_checks=3,
             error_checks=1,
-            skipped_checks=1,
         )
 
-        assert summary.total_checks == 5
+        assert summary.total_checks == 4
         assert summary.completed_checks == 3
         assert summary.error_checks == 1
-        assert summary.skipped_checks == 1
 
     def test_zero_checks(self):
         """Test summary with zero checks."""
@@ -38,7 +42,6 @@ class TestTestCaseSummary:
             total_checks=0,
             completed_checks=0,
             error_checks=0,
-            skipped_checks=0,
         )
 
         assert summary.total_checks == 0
@@ -49,7 +52,6 @@ class TestTestCaseSummary:
             total_checks=3,
             completed_checks=3,
             error_checks=0,
-            skipped_checks=0,
         )
 
         assert summary.total_checks == 3
@@ -62,7 +64,6 @@ class TestTestCaseSummary:
                 total_checks=-1,
                 completed_checks=0,
                 error_checks=0,
-                skipped_checks=0,
             )
 
     def test_counts_dont_sum_to_total(self):
@@ -71,8 +72,7 @@ class TestTestCaseSummary:
             TestCaseSummary(
                 total_checks=5,
                 completed_checks=2,
-                error_checks=1,
-                skipped_checks=1,  # Should be 2 to sum to 5
+                error_checks=1,  # Should be 3 to sum to 5
             )
 
     def test_counts_exceed_total(self):
@@ -81,8 +81,7 @@ class TestTestCaseSummary:
             TestCaseSummary(
                 total_checks=3,
                 completed_checks=2,
-                error_checks=2,
-                skipped_checks=2,  # 2+2+2=6 > 3
+                error_checks=2,  # 2+2=4 > 3
             )
 
 
@@ -93,6 +92,7 @@ class TestTestCaseResult:
         """Helper to create CheckResult for testing."""
         return CheckResult(
             check_type=check_type,
+            check_version='1.0.0',
             status=status,
             results={},
             resolved_arguments={},
@@ -126,7 +126,6 @@ class TestTestCaseResult:
             total_checks=2,
             completed_checks=2,
             error_checks=0,
-            skipped_checks=0,
         )
 
         result = TestCaseResult(
@@ -145,7 +144,7 @@ class TestTestCaseResult:
     def test_with_metadata(self):
         """Test TestCaseResult with metadata."""
         check_results = [self.create_check_result('completed')]
-        summary = TestCaseSummary(total_checks=1, completed_checks=1, error_checks=0, skipped_checks=0)  # noqa: E501
+        summary = TestCaseSummary(total_checks=1, completed_checks=1, error_checks=0)
 
         result = TestCaseResult(
             status='completed',
@@ -174,19 +173,20 @@ class TestTestCaseResult:
                 status='completed',
                 execution_context=self.create_execution_context("test-1"),
                 check_results=check_results,
-                summary=TestCaseSummary(2, 2, 0, 0),  # Wrong total
+                summary=TestCaseSummary(2, 2, 0),  # Wrong total
             )
 
     def test_summary_mismatch_completed(self):
         """Test that summary completed count mismatch raises ValueError."""
         error_check = CheckResult(
             check_type="test_check",
+            check_version='1.0.0',
             status='error',
             results={},
             resolved_arguments={},
             evaluated_at=datetime.now(UTC),
             metadata={"check_version": "1.0.0"},
-            error=CheckError("test_error", "Test error", True),
+            error=CheckError("test_error", "Test error"),
         )
         check_results = [
             self.create_check_result('completed'),
@@ -198,25 +198,26 @@ class TestTestCaseResult:
                 status='error',
                 execution_context=self.create_execution_context("test-1"),
                 check_results=check_results,
-                summary=TestCaseSummary(2, 2, 0, 0),  # Wrong completed count
+                summary=TestCaseSummary(2, 2, 0),  # Wrong completed count
             )
 
     def test_status_mismatch_should_be_error(self):
         """Test that incorrect status raises ValueError when should be error."""
         error_check = CheckResult(
             check_type="test_check",
+            check_version='1.0.0',
             status='error',
             results={},
             resolved_arguments={},
             evaluated_at=datetime.now(UTC),
             metadata={"check_version": "1.0.0"},
-            error=CheckError("test_error", "Test error", True),
+            error=CheckError("test_error", "Test error"),
         )
         check_results = [
             self.create_check_result('completed'),
             error_check,
         ]
-        summary = TestCaseSummary(2, 1, 1, 0)
+        summary = TestCaseSummary(2, 1, 1)
 
         with pytest.raises(ValueError, match="status should be 'error'"):
             TestCaseResult(
@@ -226,47 +227,7 @@ class TestTestCaseResult:
                 summary=summary,
             )
 
-    def test_status_mismatch_should_be_skip(self):
-        """Test that incorrect status raises ValueError when should be skip."""
-        check_results = [
-            self.create_check_result('completed'),
-            self.create_check_result('skip'),
-        ]
-        summary = TestCaseSummary(2, 1, 0, 1)
 
-        with pytest.raises(ValueError, match="status should be 'skip'"):
-            TestCaseResult(
-                status='completed',  # Wrong - should be skip
-                execution_context=self.create_execution_context("test-1"),
-                check_results=check_results,
-                summary=summary,
-            )
-
-    def test_status_priority_error_over_skip(self):
-        """Test that error status takes priority over skip."""
-        error_check = CheckResult(
-            check_type="test_check",
-            status='error',
-            results={},
-            resolved_arguments={},
-            evaluated_at=datetime.now(UTC),
-            metadata={"check_version": "1.0.0"},
-            error=CheckError("test_error", "Test error", True),
-        )
-        check_results = [
-            error_check,
-            self.create_check_result('skip'),
-        ]
-        summary = TestCaseSummary(2, 0, 1, 1)
-
-        result = TestCaseResult(
-            status='error',
-            execution_context=self.create_execution_context("test-1"),
-            check_results=check_results,
-            summary=summary,
-        )
-
-        assert result.status == 'error'
 
     def test_empty_check_results(self):
         """Test TestCaseResult with empty check results."""
@@ -274,7 +235,7 @@ class TestTestCaseResult:
             status='completed',
             execution_context=self.create_execution_context("test-1"),
             check_results=[],
-            summary=TestCaseSummary(0, 0, 0, 0),
+            summary=TestCaseSummary(0, 0, 0),
         )
 
         assert len(result.check_results) == 0
@@ -291,7 +252,7 @@ class TestTestCaseResult:
             status='completed',
             execution_context=execution_context,
             check_results=[],
-            summary=TestCaseSummary(0, 0, 0, 0),
+            summary=TestCaseSummary(0, 0, 0),
         )
 
         # Verify both IDs are accessible
@@ -305,16 +266,14 @@ class TestEvaluationSummary:
     def test_valid_summary(self):
         """Test creating valid EvaluationSummary."""
         summary = EvaluationSummary(
-            total_test_cases=10,
+            total_test_cases=9,
             completed_test_cases=7,
             error_test_cases=2,
-            skipped_test_cases=1,
         )
 
-        assert summary.total_test_cases == 10
+        assert summary.total_test_cases == 9
         assert summary.completed_test_cases == 7
         assert summary.error_test_cases == 2
-        assert summary.skipped_test_cases == 1
 
     def test_zero_test_cases(self):
         """Test summary with zero test cases."""
@@ -322,7 +281,6 @@ class TestEvaluationSummary:
             total_test_cases=0,
             completed_test_cases=0,
             error_test_cases=0,
-            skipped_test_cases=0,
         )
 
         assert summary.total_test_cases == 0
@@ -334,7 +292,6 @@ class TestEvaluationSummary:
                 total_test_cases=-1,
                 completed_test_cases=0,
                 error_test_cases=0,
-                skipped_test_cases=0,
             )
 
     def test_counts_dont_sum_to_total(self):
@@ -343,8 +300,7 @@ class TestEvaluationSummary:
             EvaluationSummary(
                 total_test_cases=5,
                 completed_test_cases=2,
-                error_test_cases=1,
-                skipped_test_cases=1,  # Should be 2 to sum to 5
+                error_test_cases=1,  # Should be 3 to sum to 5
             )
 
 
@@ -372,6 +328,7 @@ class TestEvaluationRunResult:
             check_results = [
                 CheckResult(
                     check_type="test_check",
+                    check_version='1.0.0',
                     status='completed',
                     results={},
                     resolved_arguments={},
@@ -379,32 +336,23 @@ class TestEvaluationRunResult:
                     metadata={"check_version": "1.0.0"},
                 ),
             ]
-            summary = TestCaseSummary(1, 1, 0, 0)
+            summary = TestCaseSummary(1, 1, 0)
         elif status == 'error':
             check_results = [
                 CheckResult(
                     check_type="test_check",
+                    check_version='1.0.0',
                     status='error',
                     results={},
                     resolved_arguments={},
                     evaluated_at=datetime.now(UTC),
                     metadata={"check_version": "1.0.0"},
-                    error=CheckError('validation_error', "Test error", True),
+                    error=CheckError('validation_error', "Test error"),
                 ),
             ]
-            summary = TestCaseSummary(1, 0, 1, 0)
-        else:  # skip
-            check_results = [
-                CheckResult(
-                    check_type="test_check",
-                    status='skip',
-                    results={},
-                    resolved_arguments={},
-                    evaluated_at=datetime.now(UTC),
-                    metadata={"check_version": "1.0.0"},
-                ),
-            ]
-            summary = TestCaseSummary(1, 0, 0, 1)
+            summary = TestCaseSummary(1, 0, 1)
+        else:
+            raise ValueError(f"Invalid status: {status}")
 
         return TestCaseResult(
             status=status,
@@ -427,7 +375,6 @@ class TestEvaluationRunResult:
             total_test_cases=2,
             completed_test_cases=2,
             error_test_cases=0,
-            skipped_test_cases=0,
         )
 
         evaluation = EvaluationRunResult(
@@ -460,7 +407,7 @@ class TestEvaluationRunResult:
             started_at=started_at,
             completed_at=completed_at,
             status='completed',
-            summary=EvaluationSummary(0, 0, 0, 0),
+            summary=EvaluationSummary(0, 0, 0),
             results=[],
             experiment=experiment,
             metadata={"custom": "value"},
@@ -478,7 +425,7 @@ class TestEvaluationRunResult:
                 started_at=datetime.now(UTC),
                 completed_at=datetime.now(UTC),
                 status='completed',
-                summary=EvaluationSummary(0, 0, 0, 0),
+                summary=EvaluationSummary(0, 0, 0),
                 results=[],
             )
 
@@ -493,7 +440,7 @@ class TestEvaluationRunResult:
                 started_at=started_at,
                 completed_at=completed_at,
                 status='completed',
-                summary=EvaluationSummary(0, 0, 0, 0),
+                summary=EvaluationSummary(0, 0, 0),
                 results=[],
             )
 
@@ -510,7 +457,7 @@ class TestEvaluationRunResult:
                 started_at=started_at,
                 completed_at=completed_at,
                 status='completed',
-                summary=EvaluationSummary(2, 2, 0, 0),  # Wrong total
+                summary=EvaluationSummary(2, 2, 0),  # Wrong total
                 results=results,
             )
 
@@ -523,7 +470,7 @@ class TestEvaluationRunResult:
             self.create_test_case_result('completed'),
             self.create_test_case_result('error'),
         ]
-        summary = EvaluationSummary(2, 1, 1, 0)
+        summary = EvaluationSummary(2, 1, 1)
 
         with pytest.raises(ValueError, match="status should be 'error'"):
             EvaluationRunResult(
@@ -535,27 +482,6 @@ class TestEvaluationRunResult:
                 results=results,
             )
 
-    def test_status_priority_error_over_skip(self):
-        """Test that error status takes priority over skip."""
-        started_at = datetime.now(UTC)
-        completed_at = datetime.now(UTC)
-
-        results = [
-            self.create_test_case_result('error'),
-            self.create_test_case_result('skip'),
-        ]
-        summary = EvaluationSummary(2, 0, 1, 1)
-
-        evaluation = EvaluationRunResult(
-            evaluation_id="eval-123",
-            started_at=started_at,
-            completed_at=completed_at,
-            status='error',
-            summary=summary,
-            results=results,
-        )
-
-        assert evaluation.status == 'error'
 
     def test_empty_results(self):
         """Test EvaluationRunResult with empty results."""
@@ -567,7 +493,7 @@ class TestEvaluationRunResult:
             started_at=started_at,
             completed_at=completed_at,
             status='completed',
-            summary=EvaluationSummary(0, 0, 0, 0),
+            summary=EvaluationSummary(0, 0, 0),
             results=[],
         )
 
@@ -578,13 +504,13 @@ class TestEvaluationRunResult:
         """Test Status enum values."""
         assert Status.COMPLETED == 'completed'
         assert Status.ERROR == 'error'
-        assert Status.SKIP == 'skip'
 
     def test_check_result_accepts_status_enum(self):
         """Test CheckResult accepts Status enum."""
         metadata = {"check_version": "1.0.0"}
         result = CheckResult(
             check_type='exact_match',
+            check_version='1.0.0',
             status=Status.COMPLETED,
             results={"passed": True},
             resolved_arguments={"actual": "test", "expected": "test"},
@@ -599,11 +525,11 @@ class TestEvaluationRunResult:
             total_checks=1,
             completed_checks=1,
             error_checks=0,
-            skipped_checks=0,
         )
         metadata = {"check_version": "1.0.0"}
         check_result = CheckResult(
             check_type='exact_match',
+            check_version='1.0.0',
             status='completed',
             results={"passed": True},
             resolved_arguments={"actual": "test", "expected": "test"},
@@ -625,17 +551,16 @@ class TestEvaluationRunResult:
             total_test_cases=1,
             completed_test_cases=1,
             error_test_cases=0,
-            skipped_test_cases=0,
         )
         test_case_summary = TestCaseSummary(
             total_checks=1,
             completed_checks=1,
             error_checks=0,
-            skipped_checks=0,
         )
         metadata = {"check_version": "1.0.0"}
         check_result = CheckResult(
             check_type='exact_match',
+            check_version='1.0.0',
             status='completed',
             results={"passed": True},
             resolved_arguments={"actual": "test", "expected": "test"},
@@ -668,7 +593,7 @@ class TestEvaluationRunResult:
             started_at=now,
             completed_at=now,
             status='completed',
-            summary=EvaluationSummary(0, 0, 0, 0),
+            summary=EvaluationSummary(0, 0, 0),
             results=[],
         )
 
@@ -696,6 +621,7 @@ class TestEvaluationRunResult:
 
         check_result = CheckResult(
             check_type="exact_match",
+            check_version='1.0.0',
             status='completed',
             results={"passed": True, "score": 1.0},
             resolved_arguments={"actual": "actual result", "expected": "expected result"},
@@ -707,7 +633,7 @@ class TestEvaluationRunResult:
             status='completed',
             execution_context=ExecutionContext(test_case=test_case, output=output),
             check_results=[check_result],
-            summary=TestCaseSummary(1, 1, 0, 0),
+            summary=TestCaseSummary(1, 1, 0),
             metadata={"test_duration": "100ms"},
         )
 
@@ -725,7 +651,7 @@ class TestEvaluationRunResult:
             started_at=now,
             completed_at=now,
             status='completed',
-            summary=EvaluationSummary(1, 1, 0, 0),
+            summary=EvaluationSummary(1, 1, 0),
             results=[test_case_result],
             experiment=experiment,
             metadata={"evaluation_type": "test"},
@@ -753,7 +679,6 @@ class TestEvaluationRunResult:
         assert row['total_checks'] == 1
         assert row['completed_checks'] == 1
         assert row['error_checks'] == 0
-        assert row['skipped_checks'] == 0
 
         # Verify check-specific data
         assert row['check_type'] == "exact_match"
@@ -799,6 +724,7 @@ class TestEvaluationRunResult:
         # Successful check
         success_check = CheckResult(
             check_type="exact_match",
+            check_version='1.0.0',
             status='completed',
             results={"passed": True},
             resolved_arguments={"actual": "actual result", "expected": "expected result"},
@@ -808,6 +734,7 @@ class TestEvaluationRunResult:
         # Failed check with error
         error_check = CheckResult(
             check_type="semantic_similarity",
+            check_version='1.0.0',
             status='error',
             results={},
             resolved_arguments={"actual": "actual result", "expected": "expected result"},
@@ -815,7 +742,6 @@ class TestEvaluationRunResult:
             error=CheckError(
                 type='timeout_error',
                 message="Check timed out",
-                recoverable=True,
             ),
         )
 
@@ -823,7 +749,7 @@ class TestEvaluationRunResult:
             status='error',
             execution_context=ExecutionContext(test_case=test_case, output=output),
             check_results=[success_check, error_check],
-            summary=TestCaseSummary(2, 1, 1, 0),
+            summary=TestCaseSummary(2, 1, 1),
         )
 
         evaluation = EvaluationRunResult(
@@ -831,7 +757,7 @@ class TestEvaluationRunResult:
             started_at=now,
             completed_at=now,
             status='error',
-            summary=EvaluationSummary(1, 0, 1, 0),
+            summary=EvaluationSummary(1, 0, 1),
             results=[test_case_result],
         )
 
@@ -854,7 +780,6 @@ class TestEvaluationRunResult:
         assert row2['check_results_passed'] is None
         assert row2['error_type'] == 'timeout_error'
         assert row2['error_message'] == "Check timed out"
-        assert row2['error_recoverable'] is True
 
         # Both rows should have same test case context
         for row in dict_list:
@@ -872,6 +797,7 @@ class TestEvaluationRunResult:
         output1 = Output(value="output1", id="output-001")
         check1 = CheckResult(
             check_type="exact_match",
+            check_version='1.0.0',
             status='completed',
             results={"passed": True},
             resolved_arguments={"actual": "output1", "expected": "expected1"},
@@ -881,7 +807,7 @@ class TestEvaluationRunResult:
             status='completed',
             execution_context=ExecutionContext(test_case1, output1),
             check_results=[check1],
-            summary=TestCaseSummary(1, 1, 0, 0),
+            summary=TestCaseSummary(1, 1, 0),
         )
 
         # Test case 2
@@ -889,24 +815,26 @@ class TestEvaluationRunResult:
         output2 = Output(value="output2", id="output-002")
         check2 = CheckResult(
             check_type="contains",
-            status='skip',
+            check_version='1.0.0',
+            status='error',
             results={},
             resolved_arguments={"actual": "output2", "expected": "expected2"},
             evaluated_at=now,
+            error=CheckError('validation_error', "Test error"),
         )
         tc_result2 = TestCaseResult(
-            status='skip',
+            status='error',
             execution_context=ExecutionContext(test_case2, output2),
             check_results=[check2],
-            summary=TestCaseSummary(1, 0, 0, 1),
+            summary=TestCaseSummary(1, 0, 1),
         )
 
         evaluation = EvaluationRunResult(
             evaluation_id="eval-multi",
             started_at=now,
             completed_at=now,
-            status='skip',
-            summary=EvaluationSummary(2, 1, 0, 1),
+            status='error',
+            summary=EvaluationSummary(2, 1, 1),
             results=[tc_result1, tc_result2],
         )
 
@@ -923,13 +851,13 @@ class TestEvaluationRunResult:
         row2 = dict_list[1]
         assert row2['test_case_id'] == "test-002"
         assert row2['check_type'] == "contains"
-        assert row2['check_status'] == 'skip'
+        assert row2['check_status'] == 'error'
         assert row2['check_results_passed'] is None
 
         # Both should have same evaluation context
         for row in dict_list:
             assert row['evaluation_id'] == "eval-multi"
-            assert row['evaluation_status'] == 'skip'
+            assert row['evaluation_status'] == 'error'
         assert pd.DataFrame(dict_list).shape[0] == 2
         pd.DataFrame(dict_list).iloc[0].transpose()
 
@@ -942,6 +870,7 @@ class TestEvaluationRunResult:
         output = Output(value="actual", id="output-pandas")
         check_result = CheckResult(
             check_type="exact_match",
+            check_version='1.0.0',
             status='completed',
             results={"passed": False, "similarity": 0.8},
             resolved_arguments={"actual": "actual", "expected": "expected"},
@@ -951,7 +880,7 @@ class TestEvaluationRunResult:
             status='completed',
             execution_context=ExecutionContext(test_case, output),
             check_results=[check_result],
-            summary=TestCaseSummary(1, 1, 0, 0),
+            summary=TestCaseSummary(1, 1, 0),
         )
 
         evaluation = EvaluationRunResult(
@@ -959,7 +888,7 @@ class TestEvaluationRunResult:
             started_at=now,
             completed_at=now,
             status='completed',
-            summary=EvaluationSummary(1, 1, 0, 0),
+            summary=EvaluationSummary(1, 1, 0),
             results=[test_case_result],
         )
 
@@ -976,7 +905,7 @@ class TestEvaluationRunResult:
             'evaluation_id', 'started_at', 'completed_at', 'evaluation_status',
             'test_case_id', 'test_case_status', 'input_data', 'expected_output',
             'actual_output', 'total_checks', 'completed_checks', 'error_checks',
-            'skipped_checks', 'check_type', 'check_status', 'check_results',
+            'check_type', 'check_status', 'check_results',
             'check_results_passed', 'resolved_arguments', 'evaluated_at',
         }
         assert expected_keys.issubset(dict_list[0].keys())
@@ -1012,6 +941,7 @@ class TestEvaluationRunResult:
         # (metadata from Check gets merged with check_version)
         check_result = CheckResult(
             check_type="exact_match",
+            check_version='1.0.0',
             status='completed',
             results={"passed": True},
             resolved_arguments={"actual": "actual", "expected": "expected"},
@@ -1027,7 +957,7 @@ class TestEvaluationRunResult:
             status='completed',
             execution_context=ExecutionContext(test_case, output),
             check_results=[check_result],
-            summary=TestCaseSummary(1, 1, 0, 0),
+            summary=TestCaseSummary(1, 1, 0),
         )
 
         evaluation = EvaluationRunResult(
@@ -1035,7 +965,7 @@ class TestEvaluationRunResult:
             started_at=now,
             completed_at=now,
             status='completed',
-            summary=EvaluationSummary(1, 1, 0, 0),
+            summary=EvaluationSummary(1, 1, 0),
             results=[test_case_result],
         )
 
@@ -1077,7 +1007,7 @@ class TestEvaluationRunResult:
                     "actual": "$.output.value",
                     "expected": "$.test_case.expected",
                 },
-                version="2.0.0",
+                version="1.0.0",
                 metadata={"priority": "high", "category": "strict"},
             ),
             Check(
@@ -1086,7 +1016,7 @@ class TestEvaluationRunResult:
                     "text": "$.output.value",
                     "phrases": ["foo"],
                 },
-                version="1.5.0",
+                version="1.0.0",
                 metadata={"priority": "medium", "timeout_ms": 1000},
             ),
         ]
@@ -1105,7 +1035,6 @@ class TestEvaluationRunResult:
         assert row1['test_case_id'] == "test-001"
         assert row1['check_type'] == "exact_match"
         assert row1['check_metadata'] == {
-            "check_version": "2.0.0",
             "priority": "high",
             "category": "strict",
         }
@@ -1116,7 +1045,6 @@ class TestEvaluationRunResult:
         assert row2['test_case_id'] == "test-001"
         assert row2['check_type'] == "contains"
         assert row2['check_metadata'] == {
-            "check_version": "1.5.0",
             "priority": "medium",
             "timeout_ms": 1000,
         }
@@ -1127,7 +1055,6 @@ class TestEvaluationRunResult:
         assert row3['test_case_id'] == "test-002"
         assert row3['check_type'] == "exact_match"
         assert row3['check_metadata'] == {
-            "check_version": "2.0.0",
             "priority": "high",
             "category": "strict",
         }
@@ -1138,7 +1065,6 @@ class TestEvaluationRunResult:
         assert row4['test_case_id'] == "test-002"
         assert row4['check_type'] == "contains"
         assert row4['check_metadata'] == {
-            "check_version": "1.5.0",
             "priority": "medium",
             "timeout_ms": 1000,
         }
@@ -1146,7 +1072,6 @@ class TestEvaluationRunResult:
 
         # Verify that all rows have the expected structure
         for row in dict_list:
-            assert 'check_version' not in row  # Should be inside check_metadata
+            assert 'check_version' in row  # Should be inside check_metadata
             assert 'check_metadata' in row
             assert isinstance(row['check_metadata'], dict)
-            assert 'check_version' in row['check_metadata']
